==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/WebGridCellIdentifierDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridCellIdentifierDescription } from "./WebGridCellIdentifierDescription";
/**
 * @hidden
 */
export let WebGridCellIdentifierDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridCellIdentifierDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridCellIdentifierDescriptionMetadata.a == null) {
                WebGridCellIdentifierDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridCellIdentifierDescriptionMetadata.c(WebGridCellIdentifierDescriptionMetadata.a);
            }
            if (a.k(WebGridCellIdentifierDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebGridCellIdentifierDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GridCellIdentifier");
            a.item("RowID", "String");
            a.item("ColumnID", "Number:int");
            a.item("RowIndex", "Number:int");
        }
        static d(a) {
            WebGridCellIdentifierDescriptionMetadata.b(a);
            a.ad("WebGridCellIdentifier", () => new WebGridCellIdentifierDescription());
            a.ac("WebGridCellIdentifier", WebGridCellIdentifierDescriptionMetadata.a);
        }
    }
    WebGridCellIdentifierDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGridCellIdentifierDescriptionMetadata, 'WebGridCellIdentifierDescriptionMetadata');
    WebGridCellIdentifierDescriptionMetadata.a = null;
    return WebGridCellIdentifierDescriptionMetadata;
})();

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm2015/lib/WebGridCellIdentifierDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridCellIdentifierDescription } from "./WebGridCellIdentifierDescription";
/**
 * @hidden
 */
export let WebGridCellIdentifierDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridCellIdentifierDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridCellIdentifierDescriptionMetadata.a == null) {
                WebGridCellIdentifierDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridCellIdentifierDescriptionMetadata.c(WebGridCellIdentifierDescriptionMetadata.a);
            }
            if (a.k(WebGridCellIdentifierDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebGridCellIdentifierDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GridCellIdentifier");
            a.item("__marshalByValue", "Boolean");
            a.item("RowID", "String");
            a.item("ColumnID", "Number:int");
            a.item("RowIndex", "Number:int");
        }
        static d(a) {
            WebGridCellIdentifierDescriptionMetadata.b(a);
            a.ae("WebGridCellIdentifier", () => new WebGridCellIdentifierDescription());
            a.ad("WebGridCellIdentifier", WebGridCellIdentifierDescriptionMetadata.a);
        }
    }
    WebGridCellIdentifierDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGridCellIdentifierDescriptionMetadata, 'WebGridCellIdentifierDescriptionMetadata');
    WebGridCellIdentifierDescriptionMetadata.a = null;
    return WebGridCellIdentifierDescriptionMetadata;
})();
